| Title: | Neutrosophic Distributions |
|---|---|
| Description: | Computes the pdf, cdf, quantile function and generating random numbers for neutrosophic distributions. This family have been developed by different authors in the recent years. See Patro and Smarandache (2016) <doi:10.5281/zenodo.571153> and Rao et al (2023) <doi:10.5281/zenodo.7832786>. |
| Authors: | Danial Mazarei [aut, cre] (ORCID: <https://orcid.org/0000-0002-3633-9298>), Mina Norouzirad [aut] (ORCID: <https://orcid.org/0000-0003-0311-6888>), Amin Roshani [aut] (ORCID: <https://orcid.org/0000-0002-3329-5330>), Gadde Srinivasa Rao [ctb] (ORCID: <https://orcid.org/0000-0002-3683-5486>), Foad Esmaeili [ctb] (ORCID: <https://orcid.org/0000-0002-9638-0807>), FCT, I.P. [fnd] (under the scope of the projects UIDB/00297/2020 and UIDP/00297/2020 (NovaMath)) |
| Maintainer: | Danial Mazarei <[email protected]> |
| License: | GPL (>= 2) |
| Version: | 2.1.1 |
| Built: | 2026-06-08 09:24:48 UTC |
| Source: | https://github.com/dmazarei/ntsdists |
It is related to failure times of 23 bearing balls.
A data.frame with 23 observations of failure times of bearing balls.
Lawless, J. F. (2003). Statistical Models and Methods for Lifetime Data, Wiley, Hoboken, NJ, USA.
Salam, S., Khan, Z., Ayed, H., Brahmia, A., Amin, A. (2021). The Neutrosophic Lognormal Model in Lifetime Data Analysis: Properties and Applications, Fuzzy Sets and Their Applications in Mathematics, Article ID 6337759.
data("balls") ballsdata("balls") balls
Density, distribution function, quantile function and random
generation for the neutrosophic Beta distribution with shape parameters
shape1 = and shape2 = .
dnsBeta(x, shape1, shape2) pnsBeta(q, shape1, shape2, lower.tail = TRUE) qnsBeta(p, shape1, shape2) rnsBeta(n, shape1, shape2)dnsBeta(x, shape1, shape2) pnsBeta(q, shape1, shape2, lower.tail = TRUE) qnsBeta(p, shape1, shape2) rnsBeta(n, shape1, shape2)
x |
a vector or matrix of observations for which the pdf needs to be computed. |
shape1 |
the first shape parameter, which must be a positive interval. |
shape2 |
the second shape parameter, which must be a positive interval. |
q |
a vector or matrix of quantiles for which the cdf needs to be computed. |
lower.tail |
logical; if TRUE (default), probabilities are
|
p |
a vector or matrix of probabilities for which the quantile needs to be computed. |
n |
number of random values to be generated. |
The neutrosophic beta distribution with parameters and
has the probability density function
for , the first shape parameter which
must be a positive interval, and ,
the second shape parameter which must also be a positive interval, and
. The function
returns the beta function and can be calculated using beta.
dnsBeta gives the density function
pnsBeta gives the distribution function
qnsBeta gives the quantile function
rnsBeta generates random values from the neutrosophic Beta distribution.
Sherwani, R. Ah. K., Naeem, M., Aslam, M., Reza, M. A., Abid, M., Abbas, S. (2021). Neutrosophic beta distribution with properties and applications. Neutrosophic Sets and Systems, 41, 209-214.
dnsBeta(x = c(0.1, 0.2), shape1 = c(1, 1), shape2 = c(2, 2)) dnsBeta(x = 0.1, shape1 = c(1, 1), shape2 = c(2, 2)) x <- matrix(c(0.1, 0.1, 0.2, 0.3, 0.5, 0.5), ncol = 2, byrow = TRUE) dnsBeta(x, shape1 = c(1, 2), shape2 = c(2, 3)) pnsBeta(q = c(0.1, 0.1), shape1 = c(3, 1), shape2 = c(1, 3), lower.tail = FALSE) pnsBeta(x, shape1 = c(1, 2), shape2 = c(2, 2)) qnsBeta(p = 0.1, shape1 = c(1, 1), shape2 = c(2, 2)) qnsBeta(p = c(0.25, 0.5, 0.75), shape1 = c(1, 2), shape2 = c(2, 2)) # Simulate 10 numbers rnsBeta(n = 10, shape1 = c(1, 2), shape2 = c(1, 1))dnsBeta(x = c(0.1, 0.2), shape1 = c(1, 1), shape2 = c(2, 2)) dnsBeta(x = 0.1, shape1 = c(1, 1), shape2 = c(2, 2)) x <- matrix(c(0.1, 0.1, 0.2, 0.3, 0.5, 0.5), ncol = 2, byrow = TRUE) dnsBeta(x, shape1 = c(1, 2), shape2 = c(2, 3)) pnsBeta(q = c(0.1, 0.1), shape1 = c(3, 1), shape2 = c(1, 3), lower.tail = FALSE) pnsBeta(x, shape1 = c(1, 2), shape2 = c(2, 2)) qnsBeta(p = 0.1, shape1 = c(1, 1), shape2 = c(2, 2)) qnsBeta(p = c(0.25, 0.5, 0.75), shape1 = c(1, 2), shape2 = c(2, 2)) # Simulate 10 numbers rnsBeta(n = 10, shape1 = c(1, 2), shape2 = c(1, 1))
Density, distribution function, quantile function and random
generation for the neutrosophic binomial distribution with
parameters size = and prob = .
dnsBinom(x, size, prob) pnsBinom(q, size, prob, lower.tail = TRUE) qnsBinom(p, size, prob) rnsBinom(n, size, prob)dnsBinom(x, size, prob) pnsBinom(q, size, prob, lower.tail = TRUE) qnsBinom(p, size, prob) rnsBinom(n, size, prob)
x |
a vector or matrix of observations for which the pdf needs to be computed. |
size |
number of trials (zero or more), which must be a positive interval. |
prob |
probability of success on each trial, |
q |
a vector or matrix of quantiles for which the cdf needs to be computed. |
lower.tail |
logical; if TRUE (default), probabilities are
|
p |
a vector or matrix of probabilities for which the quantile needs to be computed. |
n |
number of random values to be generated. |
The neutrosophic binomial distribution with parameters and
has the density
for and which must be
and .
dnsBinom gives the probability mass function
pnsBinom gives the distribution function
qnsBinom gives the quantile function
rnsBinom generates random variables from the Binomial Distribution.
Granados, C. (2022). Some discrete neutrosophic distributions with neutrosophic parameters based on neutrosophic random variables. Hacettepe Journal of Mathematics and Statistics, 51(5), 1442-1457.
# Probability of X = 17 when X follows bin(n = 20, p = [0.9,0.8]) dnsBinom(x = 17, size = 20, prob = c(0.9, 0.8)) x <- matrix(c(15, 15, 17, 18, 19, 19), ncol = 2, byrow = TRUE) dnsBinom(x = x, size = 20, prob = c(0.8, 0.9)) pnsBinom(q = 17, size = 20, prob = c(0.9, 0.8)) pnsBinom(q = c(17, 18), size = 20, prob = c(0.9, 0.8)) pnsBinom(q = x, size = 20, prob = c(0.9, 0.8)) qnsBinom(p = 0.5, size = 20, prob = c(0.8, 0.9)) qnsBinom(p = c(0.25, 0.5, 0.75), size = 20, prob = c(0.8, 0.9)) # Simulate 10 numbers rnsBinom(n = 10, size = 20, prob = c(0.8, 0.9))# Probability of X = 17 when X follows bin(n = 20, p = [0.9,0.8]) dnsBinom(x = 17, size = 20, prob = c(0.9, 0.8)) x <- matrix(c(15, 15, 17, 18, 19, 19), ncol = 2, byrow = TRUE) dnsBinom(x = x, size = 20, prob = c(0.8, 0.9)) pnsBinom(q = 17, size = 20, prob = c(0.9, 0.8)) pnsBinom(q = c(17, 18), size = 20, prob = c(0.9, 0.8)) pnsBinom(q = x, size = 20, prob = c(0.9, 0.8)) qnsBinom(p = 0.5, size = 20, prob = c(0.8, 0.9)) qnsBinom(p = c(0.25, 0.5, 0.75), size = 20, prob = c(0.8, 0.9)) # Simulate 10 numbers rnsBinom(n = 10, size = 20, prob = c(0.8, 0.9))
Density, distribution function, quantile function and random
generation for the neutrosophic discrete uniform distribution with
parameter .
dnsDiscUnif(x, k) pnsDiscUnif(q, k, lower.tail = TRUE) qnsDiscUnif(p, k) rnsDiscUnif(n, k)dnsDiscUnif(x, k) pnsDiscUnif(q, k, lower.tail = TRUE) qnsDiscUnif(p, k) rnsDiscUnif(n, k)
x |
a vector or matrix of observations for which the pdf needs to be computed. |
k |
parameter of the distribution that must be a positive finite interval. |
q |
a vector or matrix of quantiles for which the cdf needs to be computed. |
lower.tail |
logical; if TRUE (default), probabilities are
|
p |
a vector or matrix of probabilities for which the quantile needs to be computed. |
n |
number of random values to be generated. |
Let be a neutrosophic random variable and denote
as neutrosophic discrete
uniform distribution with parameter has the density
for .
dnsDiscUnif gives the probability mass function,
pnsDiscUnif gives the distribution function
qnsDiscUnif gives the quantile function
rnsDiscUnif generates random variables from the neutrosophic Discrete Uniform Distribution.
Granados, C. (2022). Some discrete neutrosophic distributions with neutrosophic parameters based on neutrosophic random variables. Hacettepe Journal of Mathematics and Statistics, 51(5), 1442-1457.
dnsDiscUnif(x = 8, k = c(10, 11)) dnsDiscUnif(x = c(8, 9), k = c(10, 11)) pnsDiscUnif(q = 2, k = c(10, 11)) qnsDiscUnif(p = 0.2, k = c(10, 11)) # Simulate 10 numbers rnsDiscUnif(n = 10, k = c(10, 11))dnsDiscUnif(x = 8, k = c(10, 11)) dnsDiscUnif(x = c(8, 9), k = c(10, 11)) pnsDiscUnif(q = 2, k = c(10, 11)) qnsDiscUnif(p = 0.2, k = c(10, 11)) # Simulate 10 numbers rnsDiscUnif(n = 10, k = c(10, 11))
Density, distribution function, quantile function and random
generation for the neutrosophic exponential distribution with the
parameter rate = .
dnsExp(x, rate) pnsExp(q, rate, lower.tail = TRUE) qnsExp(p, rate) rnsExp(n, rate)dnsExp(x, rate) pnsExp(q, rate, lower.tail = TRUE) qnsExp(p, rate) rnsExp(n, rate)
x |
a vector or matrix of observations for which the pdf needs to be computed. |
rate |
the shape parameter, which must be a positive interval. |
q |
a vector or matrix of quantiles for which the cdf needs to be computed. |
lower.tail |
logical; if TRUE (default), probabilities are
|
p |
a vector or matrix of probabilities for which the quantile needs to be computed. |
n |
number of random values to be generated. |
The neutrosophic exponential distribution with parameter
has density
for and ,
the rate parameter must be a positive interval and .
dnsExp gives the density function
pnsExp gives the distribution function
qnsExp gives the quantile function
rnsExp generates random values from the neutrosophic exponential distribution.
Duan, W., Q., Khan, Z., Gulistan, M., Khurshid, A. (2021). Neutrosophic Exponential Distribution: Modeling and Applications for Complex Data Analysis, Complexity, 2021, 1-8.
# Example 4 of Duan et al. (2021) data <- matrix(c(4, 4, 3.5, 3.5, 3.9, 4.1, 4.2, 4.2, 4.3, 4.6, 4.7, 4.7), nrow = 6, ncol = 2, byrow = TRUE) dnsExp(data, rate = c(0.23, 0.24)) dnsExp(x = c(4, 4.1), rate = c(0.23, 0.24)) dnsExp(4, rate = c(0.23, 0.23)) # The cumulative distribution function for the nuetrosophic observation (4,4.1) pnsExp(c(4, 4.1), rate = c(0.23, 0.24), lower.tail = TRUE) pnsExp(4, rate = c(0.23, 0.24)) # The first percentile qnsExp(p = 0.1, rate = 0.25) # The quantiles qnsExp(p = c(0.25, 0.5, 0.75), rate = c(0.24, 0.25)) # Simulate 10 numbers rnsExp(n = 10, rate = c(0.23, 0.24))# Example 4 of Duan et al. (2021) data <- matrix(c(4, 4, 3.5, 3.5, 3.9, 4.1, 4.2, 4.2, 4.3, 4.6, 4.7, 4.7), nrow = 6, ncol = 2, byrow = TRUE) dnsExp(data, rate = c(0.23, 0.24)) dnsExp(x = c(4, 4.1), rate = c(0.23, 0.24)) dnsExp(4, rate = c(0.23, 0.23)) # The cumulative distribution function for the nuetrosophic observation (4,4.1) pnsExp(c(4, 4.1), rate = c(0.23, 0.24), lower.tail = TRUE) pnsExp(4, rate = c(0.23, 0.24)) # The first percentile qnsExp(p = 0.1, rate = 0.25) # The quantiles qnsExp(p = c(0.25, 0.5, 0.75), rate = c(0.24, 0.25)) # Simulate 10 numbers rnsExp(n = 10, rate = c(0.23, 0.24))
Density, distribution function, quantile function and random generation for
the neutrosophic gamma distribution with parameter shape =
and scale=.
dnsGamma(x, shape, scale) pnsGamma(q, shape, scale, lower.tail = TRUE) qnsGamma(p, shape, scale) rnsGamma(n, shape, scale)dnsGamma(x, shape, scale) pnsGamma(q, shape, scale, lower.tail = TRUE) qnsGamma(p, shape, scale) rnsGamma(n, shape, scale)
x |
a vector or matrix of observations for which the pdf needs to be computed. |
shape |
the shape parameter, which must be a positive interval. |
scale |
the scale parameter, which must be a positive interval. |
q |
a vector or matrix of quantiles for which the cdf needs to be computed. |
lower.tail |
logical; if TRUE (default), probabilities are
|
p |
a vector or matrix of probabilities for which the quantile needs to be computed. |
n |
number of random values to be generated. |
The neutrosophic gamma distribution with parameters and
has density
for , , the shape
parameter which must be a positive interval and
, the scale parameter which
must be a positive interval. Here, is gamma
function implemented by gamma.
dnsGamma gives the density function
pnsGamma gives the distribution function
qnsGamma gives the quantile function
rnsGamma generates random variables from the neutrosophic gamma distribution.
Khan, Z., Al-Bossly, A., Almazah, M. M. A., and Alduais, F. S. (2021). On statistical development of neutrosophic gamma distribution with applications to complex data analysis, Complexity, 2021, Article ID 3701236.
data(remission) dnsGamma(x = remission, shape = c(1.1884, 1.1896), scale = c(7.6658, 7.7796)) pnsGamma(q = 20, shape = c(1.1884, 1.1896), scale = c(7.6658, 7.7796)) # Calculate quantiles qnsGamma(p = c(0.25, 0.5, 0.75), shape = c(1.1884, 1.1896), scale = c(7.6658, 7.7796)) # Simulate 10 numbers rnsGamma(n = 10, shape = c(1.1884, 1.1896), scale = c(7.6658, 7.7796))data(remission) dnsGamma(x = remission, shape = c(1.1884, 1.1896), scale = c(7.6658, 7.7796)) pnsGamma(q = 20, shape = c(1.1884, 1.1896), scale = c(7.6658, 7.7796)) # Calculate quantiles qnsGamma(p = c(0.25, 0.5, 0.75), shape = c(1.1884, 1.1896), scale = c(7.6658, 7.7796)) # Simulate 10 numbers rnsGamma(n = 10, shape = c(1.1884, 1.1896), scale = c(7.6658, 7.7796))
Density, distribution function, quantile function and random
generation for the neutrosophic generalized exponential
distribution with shape parameter and scale parameter
.
dnsGenExp(x, nu, delta) pnsGenExp(q, nu, delta, lower.tail = TRUE) qnsGenExp(p, nu, delta) rnsGenExp(n, nu, delta)dnsGenExp(x, nu, delta) pnsGenExp(q, nu, delta, lower.tail = TRUE) qnsGenExp(p, nu, delta) rnsGenExp(n, nu, delta)
x |
a vector or matrix of observations for which the pdf needs to be computed. |
nu |
the scale parameter, which must be a positive interval. |
delta |
the shape parameter, which must be a positive interval. |
q |
a vector or matrix of quantiles for which the cdf needs to be computed. |
lower.tail |
logical; if TRUE (default), probabilities are
|
p |
a vector or matrix of probabilities for which the quantile needs to be computed. |
n |
number of random values to be generated. |
The neutrosophic generalized exponential distribution with parameters
and has density
for , the shape parameter
which must be a positive interval, and , the
scale parameter which must also be a positive interval, and .
dnsGenExp gives the density function
pnsGenExp gives the distribution function
qnsGenExp gives the quantile function
rnsGenExp generates random variables from the neutrosophic generalized
exponential distribution.
Rao, G. S., Norouzirad, M., and Mazarei . D. (2023). Neutrosophic Generalized Exponential Distribution with Application. Neutrosophic Sets and Systems, 55, 471-485.
data(remission) dnsGenExp(x = remission, nu = c(7.9506, 8.0568), delta = c(1.2390, 1.2397)) pnsGenExp(q = 20, nu = c(7.9506, 8.0568), delta = c(1.2390, 1.2397)) # Calcluate quantiles qnsGenExp(c(0.25, 0.5, 0.75), nu = c(7.9506, 8.0568), delta = c(1.2390, 1.2397)) # Simulate 10 values rnsGenExp(n = 10, nu = c(7.9506, 8.0568), delta = c(1.2390, 1.2397))data(remission) dnsGenExp(x = remission, nu = c(7.9506, 8.0568), delta = c(1.2390, 1.2397)) pnsGenExp(q = 20, nu = c(7.9506, 8.0568), delta = c(1.2390, 1.2397)) # Calcluate quantiles qnsGenExp(c(0.25, 0.5, 0.75), nu = c(7.9506, 8.0568), delta = c(1.2390, 1.2397)) # Simulate 10 values rnsGenExp(n = 10, nu = c(7.9506, 8.0568), delta = c(1.2390, 1.2397))
Density, distribution function, quantile function and random generation for
the neutrosophic generalized pareto distribution with parameters shape =
and scale=.
dnsGenPareto(x, shape, scale) pnsGenPareto(q, shape, scale, lower.tail = TRUE) qnsGenPareto(p, shape, scale) rnsGenPareto(n, shape, scale)dnsGenPareto(x, shape, scale) pnsGenPareto(q, shape, scale, lower.tail = TRUE) qnsGenPareto(p, shape, scale) rnsGenPareto(n, shape, scale)
x |
a vector or matrix of observations for which the pdf needs to be computed. |
shape |
the shape parameter, which must be a positive interval. |
scale |
the scale parameter, which must be a positive interval. |
q |
a vector or matrix of quantiles for which the cdf needs to be computed. |
lower.tail |
logical; if TRUE (default), probabilities are
|
p |
a vector or matrix of probabilities for which the quantile needs to be computed. |
n |
number of random values to be generated. |
The neutrosophic generalized pareto distribution with parameters and
has density
for , , the shape
parameter which must be a positive interval and
, the scale parameter which
must be a positive interval.
dnsGenPareto gives the density function
pnsGenPareto gives the distribution function
qnsGenPareto gives the quantile function
rnsGenPareto generates random variables from the neutrosophic generalized pareto distribution.
Eassa, N. I., Zaher, H. M., & El-Magd, N. A. A. (2023). Neutrosophic Generalized Pareto Distribution, Mathematics and Statistics, 11(5), 827–833.
data(remission) dnsGenPareto(x = remission, shape = c(1.1884, 1.1896), scale = c(7.6658, 7.7796)) pnsGenPareto(q = 20, shape = c(1.1884, 1.1896), scale = c(7.6658, 7.7796)) # Calculate quantiles qnsGenPareto(p = c(0.25, 0.5, 0.75), shape = c(1.1884, 1.1896), scale = c(7.6658, 7.7796)) # Simulate 10 numbers rnsGenPareto(n = 10, shape = c(1.1884, 1.1896), scale = c(7.6658, 7.7796))data(remission) dnsGenPareto(x = remission, shape = c(1.1884, 1.1896), scale = c(7.6658, 7.7796)) pnsGenPareto(q = 20, shape = c(1.1884, 1.1896), scale = c(7.6658, 7.7796)) # Calculate quantiles qnsGenPareto(p = c(0.25, 0.5, 0.75), shape = c(1.1884, 1.1896), scale = c(7.6658, 7.7796)) # Simulate 10 numbers rnsGenPareto(n = 10, shape = c(1.1884, 1.1896), scale = c(7.6658, 7.7796))
Density, distribution function, quantile function and random
generation for the neutrosophic generalized Rayleigh distribution with
parameters shape = and scale = .
dnsGenRayleigh(x, shape, scale) pnsGenRayleigh(q, shape, scale, lower.tail = TRUE) qnsGenRayleigh(p, shape, scale) rnsGenRayleigh(n, shape, scale)dnsGenRayleigh(x, shape, scale) pnsGenRayleigh(q, shape, scale, lower.tail = TRUE) qnsGenRayleigh(p, shape, scale) rnsGenRayleigh(n, shape, scale)
x |
a vector or matrix of observations for which the pdf needs to be computed. |
shape |
the shape parameter, which must be a positive interval. |
scale |
the scale parameter, which must be a positive interval. |
q |
a vector or matrix of quantiles for which the cdf needs to be computed. |
lower.tail |
logical; if TRUE (default), probabilities are
|
p |
a vector or matrix of probabilities for which the quantile needs to be computed. |
n |
number of random values to be generated. |
The neutrosophic generalized Rayleigh distribution with parameters and
has the density
for , , the shape
parameter which must be a positive interval and
, the scale parameter which
must be a positive interval.
dnsGenRayleigh gives the density function
pnsGenRayleigh gives the distribution function
qnsGenRayleigh gives the quantile function
rnsGenRayleigh generates random variables from the Neutrosophic Generalized Rayleigh Distribution.
Norouzirad, M., Rao, G. S., & Mazarei, D. (2023). Neutrosophic Generalized Rayleigh Distribution with Application. Neutrosophic Sets and Systems, 58(1), 250-262.
data(remission) dnsGenRayleigh(x = remission,shape = c(1.1884, 1.1896), scale = c(7.6658, 7.7796)) pnsGenRayleigh(q = 20, shape = c(1.1884, 1.1896), scale = c(7.6658, 7.7796)) # Calculate quantiles qnsGenRayleigh(p = c(0.25, 0.5, 0.75), shape = c(1.1884, 1.1896), scale = c(7.6658, 7.7796)) # Simulate 10 values rnsGenRayleigh(n = 10, shape = c(1.1884, 1.1896), scale = c(7.6658, 7.7796))data(remission) dnsGenRayleigh(x = remission,shape = c(1.1884, 1.1896), scale = c(7.6658, 7.7796)) pnsGenRayleigh(q = 20, shape = c(1.1884, 1.1896), scale = c(7.6658, 7.7796)) # Calculate quantiles qnsGenRayleigh(p = c(0.25, 0.5, 0.75), shape = c(1.1884, 1.1896), scale = c(7.6658, 7.7796)) # Simulate 10 values rnsGenRayleigh(n = 10, shape = c(1.1884, 1.1896), scale = c(7.6658, 7.7796))
Density, distribution function, quantile function and random
generation for the neutrosophic Geometric distribution with
parameter prob = .
dnsGeom(x, prob) pnsGeom(q, prob, lower.tail = TRUE) qnsGeom(p, prob) rnsGeom(n, prob)dnsGeom(x, prob) pnsGeom(q, prob, lower.tail = TRUE) qnsGeom(p, prob) rnsGeom(n, prob)
x |
a vector or matrix of observations for which the pdf needs to be computed. |
prob |
probability of success on each trial, |
q |
a vector or matrix of quantiles for which the cdf needs to be computed. |
lower.tail |
logical; if TRUE (default), probabilities are
|
p |
a vector or matrix of probabilities for which the quantile needs to be computed. |
n |
number of random values to be generated. |
The neutrosophic Geometric distribution with parameter
has the density
for which must be
and .
dnsGeom gives the probability mass function
pnsGeom gives the distribution function
qnsGeom gives the quantile function
rnsGeom generates random variables from the Geometric Distribution.
Granados, C. (2022). Some discrete neutrosophic distributions with neutrosophic parameters based on neutrosophic random variables. Hacettepe Journal of Mathematics and Statistics, 51(5), 1442-1457.
# One person participates each week with a ticket in a lottery game, where # the probability of winning the first prize is (10^(-8), 10^(-6)). # Probability of one persons wins at the fifth year? dnsGeom(x = 5, prob = c(1e-8, 1e-6)) # Probability of one persons wins after 10 years? pnsGeom(q = 10, prob = c(1e-8, 1e-6)) pnsGeom(q = 10, prob = c(1e-8, 1e-6), lower.tail = FALSE) # Calculate the quantiles qnsGeom(p = c(0.25, 0.5, 0.75), prob = c(1e-8, 1e-6)) # Simulate 10 numbers rnsGeom(n = 10, prob = c(1e-8, 1e-6))# One person participates each week with a ticket in a lottery game, where # the probability of winning the first prize is (10^(-8), 10^(-6)). # Probability of one persons wins at the fifth year? dnsGeom(x = 5, prob = c(1e-8, 1e-6)) # Probability of one persons wins after 10 years? pnsGeom(q = 10, prob = c(1e-8, 1e-6)) pnsGeom(q = 10, prob = c(1e-8, 1e-6), lower.tail = FALSE) # Calculate the quantiles qnsGeom(p = c(0.25, 0.5, 0.75), prob = c(1e-8, 1e-6)) # Simulate 10 numbers rnsGeom(n = 10, prob = c(1e-8, 1e-6))
Density, distribution function, quantile function and random
generation for the neutrosophic Kumaraswamy distribution with
shape parameters and .
dnsKumaraswamy(x, shape1, shape2) pnsKumaraswamy(q, shape1, shape2, lower.tail = TRUE) qnsKumaraswamy(p, shape1, shape2) rnsKumaraswamy(n, shape1, shape2)dnsKumaraswamy(x, shape1, shape2) pnsKumaraswamy(q, shape1, shape2, lower.tail = TRUE) qnsKumaraswamy(p, shape1, shape2) rnsKumaraswamy(n, shape1, shape2)
x |
a vector or matrix of observations for which the pdf needs to be computed. |
shape1 |
the shape parameter, which must be a positive interval. |
shape2 |
the shape parameter, which must be a positive interval. |
q |
a vector or matrix of quantiles for which the cdf needs to be computed. |
lower.tail |
logical; if TRUE (default), probabilities are
|
p |
a vector or matrix of probabilities for which the quantile needs to be computed. |
n |
number of random values to be genelambdad. |
The neutrosophic Kumaraswamy distribution with parameters and
has density
for , and
are shape parameters.
pnsKumaraswamy gives the distribution function
dnsKumaraswamy gives the density
qnsKumaraswamy gives the quantile function
rnsKumaraswamy generates random values from the neutrosophic Kumaraswamy distribution.
Ahsan-ul-Haq, M. (2022). Neutrosophic Kumaraswamy Distribution with Engineering Application, Neutrosophic Sets and Systems, 49, 269-276.
dnsKumaraswamy(x = c(0.5, 0.1), shape1 = c(0.23, 0.24), shape2 = c(1, 2)) dnsKumaraswamy(0.5, shape1 = c(0.23, 0.24), shape2 = c(1, 2)) # The cumulative distribution function for the nuetrosophic observation (4,4.1) pnsKumaraswamy(q = c(.8, .1), shape1 = c(0.23, 0.24), shape2 = c(1, 2)) # The first percentile qnsKumaraswamy(p = 0.1, shape1 = 0.24, shape2 = 2) # The quantiles qnsKumaraswamy(p = c(0.25, 0.5, 0.75), shape1 = c(0.23, 0.24), shape2 = c(1, 2)) # Simulate 10 numbers rnsKumaraswamy(n = 10, shape1 = c(0.23, 0.24), shape2 = c(1, 2))dnsKumaraswamy(x = c(0.5, 0.1), shape1 = c(0.23, 0.24), shape2 = c(1, 2)) dnsKumaraswamy(0.5, shape1 = c(0.23, 0.24), shape2 = c(1, 2)) # The cumulative distribution function for the nuetrosophic observation (4,4.1) pnsKumaraswamy(q = c(.8, .1), shape1 = c(0.23, 0.24), shape2 = c(1, 2)) # The first percentile qnsKumaraswamy(p = 0.1, shape1 = 0.24, shape2 = 2) # The quantiles qnsKumaraswamy(p = c(0.25, 0.5, 0.75), shape1 = c(0.23, 0.24), shape2 = c(1, 2)) # Simulate 10 numbers rnsKumaraswamy(n = 10, shape1 = c(0.23, 0.24), shape2 = c(1, 2))
Density, distribution function, quantile function, and random
generation for the neutrosophic Laplace (Double Exponential)
distribution with parameters location = and
scale = .
dnsLaplace(x, location, scale) pnsLaplace(q, location, scale, lower.tail = TRUE) qnsLaplace(p, location, scale) rnsLaplace(n, location, scale)dnsLaplace(x, location, scale) pnsLaplace(q, location, scale, lower.tail = TRUE) qnsLaplace(p, location, scale) rnsLaplace(n, location, scale)
x |
a vector or matrix of observations for which the pdf needs to be computed. |
location |
the location parameter, which is the mean. |
scale |
the scale parameter, Must consist of positive values. |
q |
a vector or matrix of quantiles for which the cdf needs to be computed. |
lower.tail |
logical; if TRUE (default), probabilities are
|
p |
a vector or matrix of probabilities for which the quantile needs to be computed. |
n |
number of random values to be generated. |
The neutrosophic Laplace distribution with parameters
and has density
for , , the location parameter,
, the scale parameter which be a positive interval.
dnsLaplace gives the density function
pnsLaplace gives the distribution function
qnsLaplace gives the quantile function
rnsLaplace generates random values from the neutrosophic Laplace distribution.
Rahul, T., Malik, S. C., Raj, M. (2023). Neutrosophic Laplace Distribution with Application in Financial Data Analysis, Neutrosophic Sets and Systems, 57(1), 224-233.
dnsLaplace(x = c(4, 4.1), location = c(0.23, 0.24), scale = c(1, 2)) dnsLaplace(4, location = c(0.23, 0.24), scale = c(1, 2)) # The cumulative distribution function for the neutrosophic observation (4,4.1) pnsLaplace(q = c(4, 4.1), location = c(0.23, 0.24), scale = c(1, 2)) # The first percentile qnsLaplace(p = 0.1, location = 0.24, scale = 2) # The quantiles qnsLaplace(p = c(0.25, 0.5, 0.75), location = c(0.23, 0.24), scale = c(1, 2)) # Simulate 10 numbers rnsLaplace(n = 10, location = c(0.23, 0.24), scale = c(1, 2))dnsLaplace(x = c(4, 4.1), location = c(0.23, 0.24), scale = c(1, 2)) dnsLaplace(4, location = c(0.23, 0.24), scale = c(1, 2)) # The cumulative distribution function for the neutrosophic observation (4,4.1) pnsLaplace(q = c(4, 4.1), location = c(0.23, 0.24), scale = c(1, 2)) # The first percentile qnsLaplace(p = 0.1, location = 0.24, scale = 2) # The quantiles qnsLaplace(p = c(0.25, 0.5, 0.75), location = c(0.23, 0.24), scale = c(1, 2)) # Simulate 10 numbers rnsLaplace(n = 10, location = c(0.23, 0.24), scale = c(1, 2))
Density, distribution function, quantile function and random
generation for the neutrosophic Negative Binomial distribution with
parameters size = and prob = .
dnsNegBinom(x, size, prob) pnsNegBinom(q, size, prob, lower.tail = TRUE) qnsNegBinom(p, size, prob) rnsNegBinom(n, size, prob)dnsNegBinom(x, size, prob) pnsNegBinom(q, size, prob, lower.tail = TRUE) qnsNegBinom(p, size, prob) rnsNegBinom(n, size, prob)
x |
a vector or matrix of observations for which the pdf needs to be computed. |
size |
number of trials (zero or more), which must be a positive interval. |
prob |
probability of success on each trial, |
q |
a vector or matrix of quantiles for which the cdf needs to be computed. |
lower.tail |
logical; if TRUE (default), probabilities are
|
p |
a vector or matrix of probabilities for which the quantile needs to be computed. |
n |
number of random values to be generated. |
The neutrosophic negative binomial distribution with parameters and
has the density
for and which must be
and .
dnsNegBinom gives the probability mass function
pnsNegBinom gives the distribution function
qnsNegBinom gives the quantile function
rnsNegBinom generates random variables from the Negative Binomial Distribution.
Granados, C. (2022). Some discrete neutrosophic distributions with neutrosophic parameters based on neutrosophic random variables. Hacettepe Journal of Mathematics and Statistics, 51(5), 1442-1457.
dnsNegBinom(x = 1, size = 2, prob = c(0.5, 0.6)) pnsNegBinom(q = 1, size = 2, prob = c(0.5, 0.6)) qnsNegBinom(p = c(0.25, 0.5, 0.75), size = 2, prob = c(0.5, 0.6)) rnsNegBinom(n = 10, size = 2, prob = c(0.6, 0.6))dnsNegBinom(x = 1, size = 2, prob = c(0.5, 0.6)) pnsNegBinom(q = 1, size = 2, prob = c(0.5, 0.6)) qnsNegBinom(p = c(0.25, 0.5, 0.75), size = 2, prob = c(0.5, 0.6)) rnsNegBinom(n = 10, size = 2, prob = c(0.6, 0.6))
Density, distribution function, quantile function and random
generation for the neutrosophic generalized exponential
distribution with parameters mean = and standard deviation
sd = .
dnsNorm(x, mean, sd) pnsNorm(q, mean, sd, lower.tail = TRUE) qnsNorm(p, mean, sd) rnsNorm(n, mean, sd)dnsNorm(x, mean, sd) pnsNorm(q, mean, sd, lower.tail = TRUE) qnsNorm(p, mean, sd) rnsNorm(n, mean, sd)
x |
a vector or matrix of observations for which the pdf needs to be computed. |
mean |
the mean, which must be an interval. |
sd |
the standard deviations that must be positive. |
q |
a vector or matrix of quantiles for which the cdf needs to be computed. |
lower.tail |
logical; if TRUE (default), probabilities are
|
p |
a vector or matrix of probabilities for which the quantile needs to be computed. |
n |
number of random values to be generated. |
The neutrosophic normal distribution with parameters mean
and standard deviation has density function
}
for , the mean which must be an interval, and
, the standard deviation which must
also be a positive interval, and .
dnsNorm gives the density function
pnsNorm gives the distribution function
qnsNorm gives the quantile function
rnsNorm generates random variables from the neutrosophic normal distribution.
Patro, S. and Smarandache, F. (2016). The Neutrosophic Statistical Distribution, More Problems, More Solutions. Infinite Study.
data(balls) dnsNorm(x = balls, mean = c(72.14087, 72.94087), sd = c(37.44544, 37.29067)) pnsNorm(q = 5, mean = c(72.14087, 72.94087), sd = c(37.44544, 37.29067)) # Calculate quantiles qnsNorm(p = c(0.25, 0.5, 0.75), mean = c(9.1196, 9.2453), sd = c(10.1397, 10.4577)) # Simulate 10 values rnsNorm(n = 10, mean = c(4.141, 4.180), sd = c(0.513, 0.521))data(balls) dnsNorm(x = balls, mean = c(72.14087, 72.94087), sd = c(37.44544, 37.29067)) pnsNorm(q = 5, mean = c(72.14087, 72.94087), sd = c(37.44544, 37.29067)) # Calculate quantiles qnsNorm(p = c(0.25, 0.5, 0.75), mean = c(9.1196, 9.2453), sd = c(10.1397, 10.4577)) # Simulate 10 values rnsNorm(n = 10, mean = c(4.141, 4.180), sd = c(0.513, 0.521))
Density, distribution function, quantile function and random
generation for the neutrosophic Poisson distribution with
parameter .
dnsPois(x, lambda) pnsPois(q, lambda, lower.tail = TRUE) qnsPois(p, lambda) rnsPois(n, lambda)dnsPois(x, lambda) pnsPois(q, lambda, lower.tail = TRUE) qnsPois(p, lambda) rnsPois(n, lambda)
x |
a vector or matrix of observations for which the pdf needs to be computed. |
lambda |
the mean, which must be a positive interval. |
q |
a vector or matrix of quantiles for which the cdf needs to be computed. |
lower.tail |
logical; if TRUE (default), probabilities are
|
p |
a vector or matrix of probabilities for which the quantile needs to be computed. |
n |
number of random values to be generated. |
The neutrosophic Poisson distribution with parameter
has the density
for which must be a positive
interval and .
dnsPois gives the probability mass function
pnsPois gives the distribution function
qnsPois gives the quantile function
rnsPois generates random variables from the neutrosophic Poisson Distribution.
Alhabib, R., Ranna, M. M., Farah, H., Salama, A. A. (2018). Some neutrosophic probability distributions. Neutrosophic Sets and Systems, 22, 30-38.
# In a company, Phone employee receives phone calls, the calls arrive with # rate of [1 , 3] calls per minute, we will calculate # the probability that the employee will not receive any call within a minute dnsPois(x = 0, lambda = c(1, 3)) # the probability that employee would not receive any call within 5 minutes dnsPois(x = 0, lambda = c(5, 15)) # the probability that the employee will receive at least one call within a minute pnsPois(q = 1, lambda = c(1, 3), lower.tail = FALSE) # the probability that the employee will receive at most three calls within 5 minutes pnsPois(q = 3, lambda = c(5, 15), lower.tail = TRUE) # Calcaute the quantiles qnsPois(p = c(0.25, 0.5, 0.75), lambda = c(1, 3)) # Simulate 10 values rnsPois(n = 10, lambda = 1)# In a company, Phone employee receives phone calls, the calls arrive with # rate of [1 , 3] calls per minute, we will calculate # the probability that the employee will not receive any call within a minute dnsPois(x = 0, lambda = c(1, 3)) # the probability that employee would not receive any call within 5 minutes dnsPois(x = 0, lambda = c(5, 15)) # the probability that the employee will receive at least one call within a minute pnsPois(q = 1, lambda = c(1, 3), lower.tail = FALSE) # the probability that the employee will receive at most three calls within 5 minutes pnsPois(q = 3, lambda = c(5, 15), lower.tail = TRUE) # Calcaute the quantiles qnsPois(p = c(0.25, 0.5, 0.75), lambda = c(1, 3)) # Simulate 10 values rnsPois(n = 10, lambda = 1)
Density, distribution function, quantile function and random
generation for the neutrosophic Rayleigh distribution with
parameter .
dnsRayleigh(x, theta) pnsRayleigh(q, theta, lower.tail = TRUE) qnsRayleigh(p, theta) rnsRayleigh(n, theta)dnsRayleigh(x, theta) pnsRayleigh(q, theta, lower.tail = TRUE) qnsRayleigh(p, theta) rnsRayleigh(n, theta)
x |
a vector or matrix of observations for which the pdf needs to be computed. |
theta |
the shape parameter, which must be a positive interval. |
q |
a vector or matrix of quantiles for which the cdf needs to be computed. |
lower.tail |
logical; if TRUE (default), probabilities are
|
p |
a vector or matrix of probabilities for which the quantile needs to be computed. |
n |
number of random values to be generated. |
The neutrosophic Rayleigh distribution with parameter
has the density
for , which must be a positive
interval and .
dnsRayleigh gives the density function
pnsRayleigh gives the distribution function
qnsRayleigh gives the quantile function
rnsRayleigh generates random variables from the Neutrosophic Rayleigh Distribution.
Khan, Z., Gulistan, M., Kausar, N. and Park, C. (2021). Neutrosophic Rayleigh Model With Some Basic Characteristics and Engineering Applications, in IEEE Access, 9, 71277-71283.
data(remission) dnsRayleigh(x = remission, theta = c(9.6432, 9.8702)) pnsRayleigh(q = 20, theta = c(9.6432, 9.8702)) # Calculate quantiles qnsRayleigh(p = c(0.25, 0.5, 0.75), theta = c(9.6432, 9.8702)) # Simulate 10 values rnsRayleigh(n = 10, theta = c(9.6432, 9.8702))data(remission) dnsRayleigh(x = remission, theta = c(9.6432, 9.8702)) pnsRayleigh(q = 20, theta = c(9.6432, 9.8702)) # Calculate quantiles qnsRayleigh(p = c(0.25, 0.5, 0.75), theta = c(9.6432, 9.8702)) # Simulate 10 values rnsRayleigh(n = 10, theta = c(9.6432, 9.8702))
Density, distribution function, quantile function and random
generation for the neutrosophic Uniform distribution of a continuous
variable with parameters and .
dnsUnif(x, min, max) pnsUnif(q, min, max, lower.tail = TRUE) qnsUnif(p, min, max) rnsUnif(n, min, max)dnsUnif(x, min, max) pnsUnif(q, min, max, lower.tail = TRUE) qnsUnif(p, min, max) rnsUnif(n, min, max)
x |
a vector or matrix of observations for which the pdf needs to be computed. |
min |
lower limits of the distribution. Must be finite. |
max |
upper limits of the distribution. Must be finite. |
q |
a vector or matrix of quantiles for which the cdf needs to be computed. |
lower.tail |
logical; if TRUE (default), probabilities are
|
p |
a vector or matrix of probabilities for which the quantile needs to be computed. |
n |
number of random values to be generated. |
The neutrosophic Uniform distribution with parameters
and has the density
for lower parameter interval, ,
upper parameter interval.
dnsUnif gives the density function
pnsUnif gives the distribution function
qnsUnif gives the quantile function
rnsUnif generates random variables from the neutrosophic Uniform Distribution.
Alhabib, R., Ranna, M. M., Farah, H., & Salama, A. A. (2018). Some neutrosophic probability distributions, Neutrosophic Sets and Systems, 22, 30-38.
dnsUnif(x = 1, min = c(0, 5), max = c(15, 20)) dnsUnif(x = c(6, 10), min = c(0, 5), max = c(15, 20)) punif(q = 1, min = c(0, 5), max = c(15, 20)) punif(q = c(6, 10), min = c(0, 5), max = c(15, 20)) qnsUnif(p = c(0.25, 0.5, 0.75), min = c(0, 5), max = c(15, 20)) rnsUnif(n = 10, min = c(0, 5), max = c(15, 20))dnsUnif(x = 1, min = c(0, 5), max = c(15, 20)) dnsUnif(x = c(6, 10), min = c(0, 5), max = c(15, 20)) punif(q = 1, min = c(0, 5), max = c(15, 20)) punif(q = c(6, 10), min = c(0, 5), max = c(15, 20)) qnsUnif(p = c(0.25, 0.5, 0.75), min = c(0, 5), max = c(15, 20)) rnsUnif(n = 10, min = c(0, 5), max = c(15, 20))
Density, distribution function, quantile function and random
generation for the neutrosophic Weibull distribution with scale
parameter and shape parameter .
dnsWeibull(x, shape, scale) pnsWeibull(q, shape, scale, lower.tail = TRUE) qnsWeibull(p, shape, scale) rnsWeibull(n, shape, scale)dnsWeibull(x, shape, scale) pnsWeibull(q, shape, scale, lower.tail = TRUE) qnsWeibull(p, shape, scale) rnsWeibull(n, shape, scale)
x |
a vector or matrix of observations for which the pdf needs to be computed. |
shape |
shape parameter, which must be a positive interval. |
scale |
scale parameter, which must be a positive interval. |
q |
a vector or matrix of quantiles for which the cdf needs to be computed. |
lower.tail |
logical; if TRUE (default), probabilities are
|
p |
a vector or matrix of probabilities for which the quantile needs to be computed. |
n |
number of random values to be generated. |
The neutrosophic Rayleigh distribution with parameters
and has the density
for the shape parameter must
be a positive interval, ,
the scale parameter which be a positive interval, and .
dnsWeibull gives the density function
pnsWeibull gives the distribution function
qnsWeibull gives the quantile function
rnsWeibull generates random variables from the neutrosophic Weibull dDistribution.
Alhasan, K. F. H. and Smarandache, F. (2019). Neutrosophic Weibull distribution and Neutrosophic Family Weibull Distribution, Neutrosophic Sets and Systems, 28, 191-199.
data(remission) dnsWeibull(x = remission, shape = c(1.0519, 1.0553), scale = c(9.3370, 9.4544)) pnsWeibull(q = 20, shape = c(1.0519, 1.0553), scale = c(9.3370, 9.4544)) # Calculate quantiles qnsWeibull(p = c(0.25, 0.5, 0.75), shape = c(1.0519, 1.0553), scale = c(9.3370, 9.4544)) # Simulate 10 numbers rnsWeibull(n = 10, shape = c(1.0519, 1.0553), scale = c(9.3370, 9.4544))data(remission) dnsWeibull(x = remission, shape = c(1.0519, 1.0553), scale = c(9.3370, 9.4544)) pnsWeibull(q = 20, shape = c(1.0519, 1.0553), scale = c(9.3370, 9.4544)) # Calculate quantiles qnsWeibull(p = c(0.25, 0.5, 0.75), shape = c(1.0519, 1.0553), scale = c(9.3370, 9.4544)) # Simulate 10 numbers rnsWeibull(n = 10, shape = c(1.0519, 1.0553), scale = c(9.3370, 9.4544))
It is related to remission time in months of 128 cancer patients.
A data.frame with 128 observations of remission time in months of cancer patients.
Lee, E.T. and Wang, J. (2003), Statistical Methods for Survival Data Analysis. Vol. 476, John Wiley & Sons,Hoboken, NJ, USA.
Rao, G. S., Norouzirad, M., and Mazarei . D. (2023). Neutrosophic Generalized Exponential Distribution with Application. Neutrosophic Sets and Systems, 55, 471-485.
data("remission") remissiondata("remission") remission